"""
For displaying and managing the inventory menu
"""

from trg.game import Game
from trg.player import Player


def render_inventory(game: Game, player: Player):
    """
    For rendering the inventory menu

    TODO: Not done yet
    """
    print("This is not done yet...")
